@@ -26,7 +26,9 @@
 
 #include <gtk/gtk.h>
 #include <sys/utsname.h>
+#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
+#include <unique/unique.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -80,6 +82,10 @@ gpk_pack_get_default_filename (const gchar *directory)
 	g_object_get (control,
 		      "distro-id", &distro_id,
 		      NULL);
+
+	/* make a sane filename */
+	g_strdelimit (distro_id, ";", '-');
+
 	if (action == GPK_ACTION_ENUM_PACKAGE) {
 		entry = GTK_ENTRY (gtk_builder_get_object (builder, "entry_package"));
 		package = gtk_entry_get_text (entry);
@@ -155,12 +161,8 @@ gpk_pack_set_percentage (guint percentage)
 	/* no info */
 	if (percentage == 101) {
 		/* set pulsing */
-		if (pulse_id == 0) {
+		if (pulse_id == 0)
 			pulse_id = g_timeout_add (100, gpk_pack_percentage_pulse_cb, NULL);
-#if GLIB_CHECK_VERSION(2,25,8)
-			g_source_set_name_by_id (pulse_id, "[GpkServicePack] pulse");
-#endif
-		}
 		return;
 	}
 
@@ -349,7 +351,7 @@ gpk_pack_copy_package_lists (const gchar *filename, GError **error)
 
 	/* convert to a file */
 	data = gpk_pack_package_array_to_string (array);
-	ret = g_file_set_contents (PK_SYSTEM_PACKAGE_LIST_FILENAME, data, -1, &error_local);
+	ret = g_file_set_contents (filename, data, -1, &error_local);
 	if (!ret) {
 		g_set_error (error, 1, 0, _("Could not save to file: %s"), error_local->message);
 		g_error_free (error_local);
@@ -366,6 +368,25 @@ out:
 	return ret;
 }
 
+/**
+ * gpk_pack_reset_ui:
+ **/
+static void
+gpk_pack_reset_ui (void)
+{
+	GtkWidget *widget;
+
+	/* stop the action */
+	gpk_pack_widgets_activate (TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
+	gtk_widget_hide (widget);
+	gpk_pack_set_percentage (100);
+
+	/* blank */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
+}
+
 /**
  * gpk_pack_ready_cb:
  **/
@@ -386,15 +407,8 @@ gpk_pack_ready_cb (GObject *object, GAsyncResult *res, gpointer userdata)
 		g_error_free (error);
 	}
 
-	/* stop the action */
-	gpk_pack_widgets_activate (TRUE);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
-	gtk_widget_hide (widget);
-	gpk_pack_set_percentage (100);
-
-	/* blank */
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
-	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
+	/* reset regardless of success/failure */
+	gpk_pack_reset_ui ();
 }
 
 
@@ -517,6 +531,7 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot copy system package array"), error->message);
 			g_error_free (error);
 		}
+		gpk_pack_reset_ui ();
 		goto out;
 	}
 
@@ -614,6 +629,19 @@ out:
 	g_free (exclude);
 }
 
+/**
+ * gpk_pack_message_received_cb
+ **/
+static void
+gpk_pack_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
+{
+	GtkWindow *window;
+	if (command == UNIQUE_ACTIVATE) {
+		window = GTK_WINDOW (gtk_builder_get_object (builder, "window_prefs"));
+		gtk_window_present (window);
+	}
+}
+
 /**
  * gpk_pack_radio_updates_cb:
  **/
@@ -659,25 +687,6 @@ gpk_pack_radio_copy_cb (GtkWidget *widget2, gpointer data)
 	action = GPK_ACTION_ENUM_COPY;
 }
 
-/**
- * gpk_pack_delete_event_cb:
- **/
-static gboolean
-gpk_pack_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
-{
-	gtk_application_quit (application);
-	return FALSE;
-}
-
-/**
- * gpk_pack_button_close_cb:
- **/
-static void
-gpk_pack_button_close_cb (GtkWidget *widget, GtkApplication *application)
-{
-	gtk_application_quit (application);
-}
-
 /**
  * main:
  **/
@@ -689,9 +698,9 @@ main (int argc, char *argv[])
 	GtkWidget *widget;
 	GtkFileFilter *filter;
 	GtkEntryCompletion *completion;
-	GtkApplication *application;
+	UniqueApp *unique_app;
 	gboolean ret;
-	GSettings *settings = NULL;
+	GConfClient *gconf_client = NULL;
 	gchar *option = NULL;
 	gchar *package = NULL;
 	gchar *with_array = NULL;
@@ -741,7 +750,14 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	application = gtk_application_new ("org.freedesktop.PackageKit.ServicePack", &argc, &argv);
+	unique_app = unique_app_new ("org.freedesktop.PackageKit.ServicePack", NULL);
+	if (unique_app_is_running (unique_app)) {
+		egg_debug ("You have another instance running. This program will now close");
+		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
+		goto out_unique;
+	}
+	g_signal_connect (unique_app, "message-received",
+			  G_CALLBACK (gpk_pack_message_received_cb), NULL);
 
 	/* use a client to download packages */
 	client = pk_client_new ();
@@ -767,15 +783,13 @@ main (int argc, char *argv[])
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-	gtk_application_add_window (application, GTK_WINDOW (main_window));
 
 	/* Hide window first so that the dialogue resizes itself without redrawing */
 	gtk_widget_hide (main_window);
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GPK_ICON_SERVICE_PACK);
 
 	/* Get the main window quit */
-	g_signal_connect (main_window, "delete-event",
-			  G_CALLBACK (gpk_pack_delete_event_cb), application);
+	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
 	filter = gtk_file_filter_new ();
@@ -799,7 +813,7 @@ main (int argc, char *argv[])
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_radio_copy_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_close_cb), application);
+	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_create"));
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_create_cb), NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -809,8 +823,8 @@ main (int argc, char *argv[])
 	gtk_widget_hide (widget);
 
 	/* autocompletion can be turned off as it's slow */
-	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
-	ret = g_settings_get_boolean (settings, GPK_SETTINGS_AUTOCOMPLETE);
+	gconf_client = gconf_client_get_default ();
+	ret = gconf_client_get_bool (gconf_client, GPK_CONF_AUTOCOMPLETE, NULL);
 	if (ret) {
 		/* create the completion object */
 		completion = gpk_package_entry_completion_new ();
@@ -847,14 +861,15 @@ main (int argc, char *argv[])
 
 	gtk_widget_show (main_window);
 
-	/* run */
-	gtk_application_run (application);
+	/* wait */
+	gtk_main ();
 
 out_build:
 	g_object_unref (builder);
-	g_object_unref (application);
-	if (settings != NULL)
-		g_object_unref (settings);
+out_unique:
+	g_object_unref (unique_app);
+	if (gconf_client != NULL)
+		g_object_unref (gconf_client);
 	if (control != NULL)
 		g_object_unref (control);
 	if (client != NULL)
