@@ -35,9 +35,8 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#ifdef HAVE_NOTIFY
+#include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
-#endif
 #include <packagekit-glib2/packagekit.h>
 
 #include "egg-debug.h"
@@ -57,21 +56,22 @@ static void     gpk_watch_finalize	(GObject       *object);
 
 #define GPK_WATCH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPK_TYPE_WATCH, GpkWatchPrivate))
 #define GPK_WATCH_MAXIMUM_TOOLTIP_LINES		10
+#define GPK_WATCH_GCONF_PROXY_HTTP		"/system/http_proxy"
+#define GPK_WATCH_GCONF_PROXY_FTP		"/system/proxy"
 #define GPK_WATCH_SET_PROXY_RATE_LIMIT		200 /* ms */
 
 struct GpkWatchPrivate
 {
 	PkControl		*control;
 	GtkStatusIcon		*status_icon;
-	GPtrArray		*cached_messages;
 	GPtrArray		*restart_package_names;
-	NotifyNotification	*notification_cached_messages;
+	NotifyNotification	*notification_message;
 	GpkInhibit		*inhibit;
 	GpkModalDialog		*dialog;
 	PkTask			*task;
 	PkTransactionList	*tlist;
 	PkRestartEnum		 restart;
-	GSettings		*settings;
+	GConfClient		*gconf_client;
 	guint			 set_proxy_id;
 	gchar			*error_details;
 	gboolean		 hide_warning;
@@ -81,19 +81,6 @@ struct GpkWatchPrivate
 	gchar			*transaction_id;
 };
 
-typedef struct {
-	PkMessageEnum	 type;
-	gchar		*tid;
-	gchar		*details;
-} GpkWatchCachedMessage;
-
-enum {
-	GPK_WATCH_COLUMN_TEXT,
-	GPK_WATCH_COLUMN_TID,
-	GPK_WATCH_COLUMN_DETAILS,
-	GPK_WATCH_COLUMN_LAST
-};
-
 G_DEFINE_TYPE (GpkWatch, gpk_watch, G_TYPE_OBJECT)
 
 /**
@@ -108,19 +95,6 @@ gpk_watch_class_init (GpkWatchClass *klass)
 	g_type_class_add_private (klass, sizeof (GpkWatchPrivate));
 }
 
-/**
- * gpk_watch_cached_message_free:
- **/
-static void
-gpk_watch_cached_message_free (GpkWatchCachedMessage *cached_message)
-{
-	if (cached_message == NULL)
-		return;
-	g_free (cached_message->tid);
-	g_free (cached_message->details);
-	g_free (cached_message);
-}
-
 /**
  * gpk_watch_get_restart_required_tooltip:
  **/
@@ -186,7 +160,6 @@ gpk_watch_refresh_tooltip (GpkWatch *watch)
 	guint i;
 	guint idx = 0;
 	PkProgress *progress;
-	guint len;
 	GString *string;
 	PkStatusEnum status;
 	PkRoleEnum role;
@@ -206,16 +179,6 @@ gpk_watch_refresh_tooltip (GpkWatch *watch)
 			g_string_append (string, text);
 		g_free (text);
 
-		/* do we have any cached messages to show? */
-		len = watch->priv->cached_messages->len;
-		if (len > 0) {
-			if (string->len > 0)
-				g_string_append_c (string, '\n');
-			g_string_append_printf (string, ngettext ("%i message from the package manager",
-								  "%i messages from the package manager", len), len);
-			goto out;
-		}
-
 		egg_debug ("nothing to show");
 		goto out;
 	}
@@ -272,7 +235,7 @@ gpk_watch_task_list_to_status_bitfield (GpkWatch *watch)
 		goto out;
 
 	/* do we watch active transactions */
-	watch_active = g_settings_get_boolean (watch->priv->settings, GPK_SETTINGS_WATCH_ACTIVE_TRANSACTIONS);
+	watch_active = gconf_client_get_bool (watch->priv->gconf_client, GPK_CONF_WATCH_ACTIVE_TRANSACTIONS, NULL);
 
 	/* add each status to a list */
 	for (i=0; i<array->len; i++) {
@@ -304,7 +267,6 @@ gpk_watch_refresh_icon (GpkWatch *watch)
 	const gchar *icon_name = NULL;
 	PkBitfield status;
 	gint value = -1;
-	guint len;
 
 	g_return_val_if_fail (GPK_IS_WATCH (watch), FALSE);
 
@@ -361,14 +323,6 @@ gpk_watch_refresh_icon (GpkWatch *watch)
 		icon_name = gpk_restart_enum_to_icon_name (watch->priv->restart);
 		goto out;
 	}
-
-	/* do we have any cached messages to show? */
-	len = watch->priv->cached_messages->len;
-	if (len > 0) {
-		icon_name = "pk-setup";
-		goto out;
-	}
-
 out:
 	/* no icon, hide */
 	if (icon_name == NULL) {
@@ -380,7 +334,6 @@ out:
 	return TRUE;
 }
 
-#ifdef HAVE_NOTIFY
 /**
  * gpk_watch_libnotify_cb:
  **/
@@ -390,8 +343,8 @@ gpk_watch_libnotify_cb (NotifyNotification *notification, gchar *action, gpointe
 	GpkWatch *watch = GPK_WATCH (data);
 
 	if (g_strcmp0 (action, "do-not-show-notify-complete") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_COMPLETED);
-		g_settings_set_boolean (watch->priv->settings, GPK_SETTINGS_NOTIFY_COMPLETED, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_COMPLETED);
+		gconf_client_set_bool (watch->priv->gconf_client, GPK_CONF_NOTIFY_COMPLETED, FALSE, NULL);
 
 	} else if (g_strcmp0 (action, "show-error-details") == 0) {
 		/* TRANSLATORS: The detailed error if the user clicks "more info" */
@@ -401,7 +354,36 @@ gpk_watch_libnotify_cb (NotifyNotification *notification, gchar *action, gpointe
 		egg_warning ("unknown action id: %s", action);
 	}
 }
-#endif
+
+/**
+ * gpk_watch_about_dialog_url_cb:
+ **/
+static void
+gpk_watch_about_dialog_url_cb (GtkAboutDialog *about, const char *address, gpointer data)
+{
+	GError *error = NULL;
+	gboolean ret;
+	GdkScreen *gscreen;
+	gchar *url;
+	gchar *protocol = (gchar*) data;
+
+	if (protocol != NULL)
+		url = g_strconcat (protocol, address, NULL);
+	else
+		url = g_strdup (address);
+
+	gscreen = gtk_window_get_screen (GTK_WINDOW (about));
+
+	ret = gtk_show_uri (gscreen, url, gtk_get_current_event_time (), &error);
+
+	if (!ret) {
+		/* TRANSLATORS: We couldn't launch the tool, normally a packaging problem */
+		gpk_error_dialog (_("Internal error"), _("Failed to show url"), error->message);
+		g_error_free (error);
+	}
+
+	g_free (url);
+}
 
 /**
  * gpk_watch_show_about_cb:
@@ -440,6 +422,9 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "", _(license[1]), "",
 				     _(license[2]), "", _(license[3]), "",  NULL);
 
+	gtk_about_dialog_set_url_hook (gpk_watch_about_dialog_url_cb, NULL, NULL);
+	gtk_about_dialog_set_email_hook (gpk_watch_about_dialog_url_cb, (gpointer) "mailto:", NULL);
+
 	gtk_window_set_default_icon_name (GPK_ICON_SOFTWARE_LOG);
 	gtk_show_about_dialog (NULL,
 			       "version", VERSION,
@@ -489,121 +474,6 @@ gpk_watch_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 times
 		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
 }
 
-/**
- * gpk_watch_menu_show_messages_cb:
- **/
-static void
-gpk_watch_menu_show_messages_cb (GtkMenuItem *item, gpointer data)
-{
-	GpkWatch *watch = GPK_WATCH (data);
-	GtkBuilder *builder;
-	GtkWidget *main_window;
-	GtkWidget *widget;
-	GtkListStore *list_store;
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-	GtkTreeIter iter;
-	GtkTreeModel *model;
-	guint i;
-	GpkWatchCachedMessage *cached_message;
-	guint retval;
-	GError *error = NULL;
-
-	/* get UI */
-	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-repo.ui", &error);
-	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
-		goto out_build;
-	}
-
-	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_repo"));
-	gtk_window_set_icon_name (GTK_WINDOW (main_window), GPK_ICON_SOFTWARE_LOG);
-	gtk_window_set_title (GTK_WINDOW (main_window), _("Package Manager Messages"));
-
-	/* set a size, if the screen allows */
-	gpk_window_set_size_request (GTK_WINDOW(main_window), 500, 200);
-
-	/* Get the main window quit */
-	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
-
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
-	gtk_widget_hide (widget);
-
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_detail"));
-	gtk_widget_hide (widget);
-
-	/* create list stores */
-	list_store = gtk_list_store_new (GPK_WATCH_COLUMN_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
-
-	/* create repo tree view */
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_repo"));
-	gtk_tree_view_set_model (GTK_TREE_VIEW (widget), GTK_TREE_MODEL (list_store));
-
-	/* column for text */
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set (renderer, "yalign", 0.0, NULL);
-	g_object_set (renderer, "wrap-mode", PANGO_WRAP_WORD, NULL);
-	g_object_set (renderer, "wrap-width", 400, NULL);
-
-	/* TRANSLATORS: column for the message type */
-	column = gtk_tree_view_column_new_with_attributes (_("Message"), renderer,
-							   "markup", GPK_WATCH_COLUMN_TEXT, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, GPK_WATCH_COLUMN_TEXT);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(widget), column);
-
-	/* column for details */
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set (renderer, "yalign", 0.0, NULL);
-	g_object_set (renderer, "wrap-mode", PANGO_WRAP_WORD, NULL);
-	g_object_set (renderer, "wrap-width", 400, NULL);
-
-	/* TRANSLATORS: column for the message description */
-	column = gtk_tree_view_column_new_with_attributes (_("Details"), renderer,
-							   "markup", GPK_WATCH_COLUMN_DETAILS, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, GPK_WATCH_COLUMN_TEXT);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(widget), column);
-
-	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(widget));
-
-	/* add items to treeview */
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW(widget));
-	for (i=0; i<watch->priv->cached_messages->len; i++) {
-		cached_message = g_ptr_array_index (watch->priv->cached_messages, i);
-		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set (list_store, &iter,
-				    GPK_WATCH_COLUMN_TEXT, gpk_message_enum_to_localised_text (cached_message->type),
-				    GPK_WATCH_COLUMN_TID, cached_message->tid,
-				    GPK_WATCH_COLUMN_DETAILS, cached_message->details,
-				    -1);
-	}
-
-	/* show window */
-	gtk_widget_show (main_window);
-
-	/* focus back to the close button */
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	gtk_widget_grab_focus (widget);
-
-	/* wait */
-	gtk_main ();
-
-	gtk_widget_hide (main_window);
-
-	g_ptr_array_set_size (watch->priv->cached_messages, 0);
-
-	g_object_unref (list_store);
-out_build:
-	g_object_unref (builder);
-
-	/* refresh UI */
-	gpk_watch_refresh_icon (watch);
-	gpk_watch_refresh_tooltip (watch);
-}
-
 /**
  * gpk_watch_set_status:
  **/
@@ -880,7 +750,6 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon, GpkWatch *watch)
 	GtkMenu *menu = (GtkMenu*) gtk_menu_new ();
 	GtkWidget *widget;
 	GtkWidget *image;
-	guint len;
 	gboolean show_hide = FALSE;
 	gboolean can_restart = FALSE;
 
@@ -891,19 +760,6 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon, GpkWatch *watch)
 	/* add jobs as drop down */
 	gpk_watch_populate_menu_with_jobs (watch, menu);
 
-	/* any messages to show? */
-	len = watch->priv->cached_messages->len;
-	if (len > 0) {
-		/* TRANSLATORS: messages from the transaction */
-		widget = gtk_image_menu_item_new_with_mnemonic (_("_Show messages"));
-		image = gtk_image_new_from_icon_name ("edit-paste", GTK_ICON_SIZE_MENU);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
-		g_signal_connect (G_OBJECT (widget), "activate",
-				  G_CALLBACK (gpk_watch_menu_show_messages_cb), watch);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
-		show_hide = TRUE;
-	}
-
 	/* log out session */
 	if (watch->priv->restart == PK_RESTART_ENUM_SESSION ||
 	    watch->priv->restart == PK_RESTART_ENUM_SECURITY_SESSION) {
@@ -957,27 +813,26 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon, GpkWatch *watch)
 static gchar *
 gpk_watch_get_proxy_ftp (GpkWatch *watch)
 {
-	gchar *connection = NULL;
-#ifdef USE_GCONF_COMPAT_GNOME_VFS
 	gchar *mode = NULL;
+	gchar *connection = NULL;
 	gchar *host = NULL;
 	gint port;
 
 	g_return_val_if_fail (GPK_IS_WATCH (watch), NULL);
 
 	/* common case, a direct connection */
-	mode = g_settings_get_string (watch->priv->settings, "/system/proxy/mode");
+	mode = gconf_client_get_string (watch->priv->gconf_client, "/system/proxy/mode", NULL);
 	if (g_strcmp0 (mode, "none") == 0) {
 		egg_debug ("not using session proxy");
 		goto out;
 	}
 
-	host = g_settings_get_string (watch->priv->settings, "/system/proxy/ftp_host");
+	host = gconf_client_get_string (watch->priv->gconf_client, "/system/proxy/ftp_host", NULL);
 	if (egg_strzero (host)) {
 		egg_debug ("no hostname for ftp proxy");
 		goto out;
 	}
-	port = g_settings_get_int (watch->priv->settings, "/system/proxy/ftp_port");
+	port = gconf_client_get_int (watch->priv->gconf_client, "/system/proxy/ftp_port", NULL);
 
 	/* ftp has no username or password */
 	if (port == 0)
@@ -987,7 +842,6 @@ gpk_watch_get_proxy_ftp (GpkWatch *watch)
 out:
 	g_free (mode);
 	g_free (host);
-#endif
 	return connection;
 }
 
@@ -998,46 +852,45 @@ out:
 static gchar *
 gpk_watch_get_proxy_http (GpkWatch *watch)
 {
-	gchar *proxy_http = NULL;
-#ifdef USE_GCONF_COMPAT_GNOME_VFS
 	gchar *mode = NULL;
 	gchar *host = NULL;
 	gchar *auth = NULL;
 	gchar *connection = NULL;
+	gchar *proxy_http = NULL;
 	gint port;
 	gboolean ret;
 
 	g_return_val_if_fail (GPK_IS_WATCH (watch), NULL);
 
 	/* common case, a direct connection */
-	mode = g_settings_get_string (watch->priv->settings, "/system/proxy/mode");
+	mode = gconf_client_get_string (watch->priv->gconf_client, "/system/proxy/mode", NULL);
 	if (g_strcmp0 (mode, "none") == 0) {
 		egg_debug ("not using session proxy");
 		goto out;
 	}
 
 	/* do we use this? */
-	ret = g_settings_get_boolean (watch->priv->settings, "/system/http_proxy/use_http_proxy");
+	ret = gconf_client_get_bool (watch->priv->gconf_client, "/system/http_proxy/use_http_proxy", NULL);
 	if (!ret) {
 		egg_debug ("not using http proxy");
 		goto out;
 	}
 
 	/* http has 4 parameters */
-	host = g_settings_get_string (watch->priv->settings, "/system/http_proxy/host");
+	host = gconf_client_get_string (watch->priv->gconf_client, "/system/http_proxy/host", NULL);
 	if (egg_strzero (host)) {
 		egg_debug ("no hostname for http proxy");
 		goto out;
 	}
 
 	/* user and password are both optional */
-	ret = g_settings_get_boolean (watch->priv->settings, "/system/http_proxy/use_authentication");
+	ret = gconf_client_get_bool (watch->priv->gconf_client, "/system/http_proxy/use_authentication", NULL);
 	if (ret) {
 		gchar *user = NULL;
 		gchar *password = NULL;
 
-		user = g_settings_get_string (watch->priv->settings, "/system/http_proxy/authentication_user");
-		password = g_settings_get_string (watch->priv->settings, "/system/http_proxy/authentication_password");
+		user = gconf_client_get_string (watch->priv->gconf_client, "/system/http_proxy/authentication_user", NULL);
+		password = gconf_client_get_string (watch->priv->gconf_client, "/system/http_proxy/authentication_password", NULL);
 
 		if (user != NULL && password != NULL)
 			auth = g_strdup_printf ("%s:%s", user, password);
@@ -1051,7 +904,7 @@ gpk_watch_get_proxy_http (GpkWatch *watch)
 	}
 
 	/* port is optional too */
-	port = g_settings_get_int (watch->priv->settings, "/system/http_proxy/port");
+	port = gconf_client_get_int (watch->priv->gconf_client, "/system/http_proxy/port", NULL);
 	if (port == 0)
 		connection = g_strdup (host);
 	else
@@ -1067,7 +920,6 @@ out:
 	g_free (connection);
 	g_free (auth);
 	g_free (host);
-#endif
 	return proxy_http;
 }
 
@@ -1128,67 +980,20 @@ gpk_watch_set_proxies (GpkWatch *watch)
 	}
 	watch->priv->set_proxy_id = g_timeout_add (GPK_WATCH_SET_PROXY_RATE_LIMIT,
 							(GSourceFunc) gpk_watch_set_proxies_ratelimit, watch);
-#if GLIB_CHECK_VERSION(2,25,8)
-	g_source_set_name_by_id (watch->priv->set_proxy_id, "[GpkWatch] set-proxies");
-#endif
 	return TRUE;
 }
 
-#if PK_CHECK_VERSION(0,6,4)
 /**
- * gpk_watch_set_root_cb:
- **/
-static void
-gpk_watch_set_root_cb (GObject *object, GAsyncResult *res, GpkWatch *watch)
-{
-	PkControl *control = PK_CONTROL (object);
-	GError *error = NULL;
-	gboolean ret;
-
-	/* get the result */
-	ret = pk_control_set_root_finish (control, res, &error);
-	if (!ret) {
-		egg_warning ("failed to set install root: %s", error->message);
-		g_error_free (error);
-		return;
-	}
-}
-
-/**
- * gpk_watch_set_root:
- **/
-static void
-gpk_watch_set_root (GpkWatch *watch)
-{
-	gchar *root;
-
-	/* get install root */
-	root = g_settings_get_string (watch->priv->settings, GPK_SETTINGS_INSTALL_ROOT);
-	if (root == NULL) {
-		egg_warning ("could not read install root");
-		goto out;
-	}
-
-	pk_control_set_root_async (watch->priv->control, root, watch->priv->cancellable,
-				   (GAsyncReadyCallback) gpk_watch_set_root_cb, watch);
-out:
-	g_free (root);
-}
-#else
-static void gpk_watch_set_root (GpkWatch *watch) {}
-#endif
-
-/**
- * gpk_watch_key_changed_cb:
+ * gpk_watch_gconf_key_changed_cb:
  *
- * We might have to do things when the keys change; do them here.
+ * We might have to do things when the gconf keys change; do them here.
  **/
 static void
-gpk_watch_key_changed_cb (GSettings *client, const gchar *key, GpkWatch *watch)
+gpk_watch_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpkWatch *watch)
 {
 	egg_debug ("keys have changed");
+	/* set the proxy */
 	gpk_watch_set_proxies (watch);
-	gpk_watch_set_root (watch);
 }
 
 /**
@@ -1226,7 +1031,6 @@ gpk_watch_set_connected (GpkWatch *watch, gboolean connected)
 	gpk_watch_refresh_icon (watch);
 	gpk_watch_refresh_tooltip (watch);
 	gpk_watch_set_proxies (watch);
-	gpk_watch_set_root (watch);
 }
 
 /**
@@ -1266,8 +1070,8 @@ gpk_watch_is_message_ignored (GpkWatch *watch, PkMessageEnum message)
 	gchar **ignored = NULL;
 	const gchar *message_str;
 
-	/* get from settings */
-	ignored_str = g_settings_get_string (watch->priv->settings, GPK_SETTINGS_IGNORED_MESSAGES);
+	/* get from gconf */
+	ignored_str = gconf_client_get_string (watch->priv->gconf_client, GPK_CONF_IGNORED_MESSAGES, NULL);
 	if (ignored_str == NULL) {
 		egg_warning ("could not read ignored list");
 		goto out;
@@ -1307,7 +1111,6 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 	GError *error = NULL;
 	gboolean value;
 	NotifyNotification *notification;
-	GpkWatchCachedMessage *cached_message;
 	PkMessageEnum type;
 	gchar *details;
 
@@ -1319,6 +1122,12 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 		      "details", &details,
 		      NULL);
 
+	/* this is message unrecognised */
+	if (gpk_message_enum_to_localised_text (type) == NULL) {
+		egg_warning ("message unrecognized, and thus ignored: %i", type);
+		goto out;
+	}
+
 	/* is ignored */
 	ret = gpk_watch_is_message_ignored (watch, type);
 	if (ret) {
@@ -1326,16 +1135,9 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 		goto out;
 	}
 
-	/* add to list */
-	cached_message = g_new0 (GpkWatchCachedMessage, 1);
-	cached_message->type = type;
-	cached_message->tid = NULL;
-	cached_message->details = g_strdup (details);
-	g_ptr_array_add (watch->priv->cached_messages, cached_message);
-
 	/* close existing */
-	if (watch->priv->notification_cached_messages != NULL) {
-		ret = notify_notification_close (watch->priv->notification_cached_messages, &error);
+	if (watch->priv->notification_message != NULL) {
+		ret = notify_notification_close (watch->priv->notification_message, &error);
 		if (!ret) {
 			egg_warning ("error: %s", error->message);
 			g_error_free (error);
@@ -1344,14 +1146,14 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 	}
 
 	/* are we accepting notifications */
-	value = g_settings_get_boolean (watch->priv->settings, GPK_SETTINGS_NOTIFY_MESSAGE);
+	value = gconf_client_get_bool (watch->priv->gconf_client, GPK_CONF_NOTIFY_MESSAGE, NULL);
 	if (!value) {
-		egg_debug ("not showing notification as prevented in settings");
+		egg_debug ("not showing notification as prevented in gconf");
 		goto out;
 	}
 
 	/* do the bubble */
-	notification = notify_notification_new_with_status_icon (_("New package manager message"), NULL, "emblem-important", watch->priv->status_icon);
+	notification = notify_notification_new_with_status_icon (gpk_message_enum_to_localised_text (type), details, "emblem-important", watch->priv->status_icon);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	ret = notify_notification_show (notification, &error);
@@ -1359,7 +1161,7 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 		egg_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
-	watch->priv->notification_cached_messages = notification;
+	watch->priv->notification_message = notification;
 out:
 	g_free (details);
 }
@@ -1394,9 +1196,9 @@ gpk_watch_process_error_code (GpkWatch *watch, PkError *error_code)
 	}
 
 	/* are we accepting notifications */
-	value = g_settings_get_boolean (watch->priv->settings, GPK_SETTINGS_NOTIFY_ERROR);
+	value = gconf_client_get_bool (watch->priv->gconf_client, GPK_CONF_NOTIFY_ERROR, NULL);
 	if (!value) {
-		egg_debug ("not showing notification as prevented in settings");
+		egg_debug ("not showing notification as prevented in gconf");
 		goto out;
 	}
 
@@ -1557,9 +1359,9 @@ gpk_watch_adopt_cb (PkClient *client, GAsyncResult *res, GpkWatch *watch)
 	}
 
 	/* are we accepting notifications */
-	ret = g_settings_get_boolean (watch->priv->settings, GPK_SETTINGS_NOTIFY_COMPLETED);
+	ret = gconf_client_get_bool (watch->priv->gconf_client, GPK_CONF_NOTIFY_COMPLETED, NULL);
 	if (!ret) {
-		egg_debug ("not showing notification as prevented in settings");
+		egg_debug ("not showing notification as prevented in gconf");
 		goto out;
 	}
 
@@ -1760,19 +1562,17 @@ gpk_watch_init (GpkWatch *watch)
 {
 	watch->priv = GPK_WATCH_GET_PRIVATE (watch);
 	watch->priv->error_details = NULL;
-	watch->priv->notification_cached_messages = NULL;
+	watch->priv->notification_message = NULL;
 	watch->priv->transaction_id = NULL;
 	watch->priv->restart = PK_RESTART_ENUM_NONE;
 	watch->priv->hide_warning = FALSE;
 	watch->priv->console = egg_console_kit_new ();
 	watch->priv->cancellable = g_cancellable_new ();
 	watch->priv->array_progress = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	watch->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
-	g_signal_connect (watch->priv->settings, "changed", G_CALLBACK (gpk_watch_key_changed_cb), watch);
+	watch->priv->gconf_client = gconf_client_get_default ();
 
 	watch->priv->status_icon = gtk_status_icon_new ();
 	watch->priv->set_proxy_id = 0;
-	watch->priv->cached_messages = g_ptr_array_new_with_free_func ((GDestroyNotify) gpk_watch_cached_message_free);
 	watch->priv->restart_package_names = g_ptr_array_new_with_free_func (g_free);
 	watch->priv->task = PK_TASK(gpk_task_new ());
 	g_object_set (watch->priv->task,
@@ -1810,9 +1610,18 @@ gpk_watch_init (GpkWatch *watch)
 	g_signal_connect (watch->priv->tlist, "removed",
 			  G_CALLBACK (gpk_watch_transaction_list_removed_cb), watch);
 
+	/* watch proxy keys */
+	gconf_client_add_dir (watch->priv->gconf_client, GPK_WATCH_GCONF_PROXY_HTTP,
+			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_add_dir (watch->priv->gconf_client, GPK_WATCH_GCONF_PROXY_FTP,
+			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (watch->priv->gconf_client, GPK_WATCH_GCONF_PROXY_HTTP,
+				 (GConfClientNotifyFunc) gpk_watch_gconf_key_changed_cb, watch, NULL, NULL);
+	gconf_client_notify_add (watch->priv->gconf_client, GPK_WATCH_GCONF_PROXY_FTP,
+				 (GConfClientNotifyFunc) gpk_watch_gconf_key_changed_cb, watch, NULL, NULL);
+
 	/* set the proxy */
 	gpk_watch_set_proxies (watch);
-	gpk_watch_set_root (watch);
 }
 
 /**
@@ -1841,12 +1650,11 @@ gpk_watch_finalize (GObject *object)
 	g_object_unref (watch->priv->console);
 	g_object_unref (watch->priv->control);
 	g_object_unref (watch->priv->dialog);
-	g_object_unref (watch->priv->settings);
+	g_object_unref (watch->priv->gconf_client);
 	g_object_unref (watch->priv->inhibit);
 	g_object_unref (watch->priv->status_icon);
 	g_object_unref (watch->priv->tlist);
 	g_ptr_array_unref (watch->priv->array_progress);
-	g_ptr_array_unref (watch->priv->cached_messages);
 	g_ptr_array_unref (watch->priv->restart_package_names);
 
 	G_OBJECT_CLASS (gpk_watch_parent_class)->finalize (object);
